@@ -149,12 +149,14 @@ int main(int argc, char *argv[])
         ST_Destroy( (ST_TIFF *) tif );
     else
         XTIFFClose(tif);
+    GTIFDeaccessCSV();
     return 0;
 		
   failure:
     fprintf(stderr,"failure in listgeo\n");
     if (tif) XTIFFClose(tif);
     if (gtif) GTIFFree(gtif);
+    GTIFDeaccessCSV();
     return 1;
 }
 
@@ -292,7 +294,10 @@ static void WriteTFWFile( GTIF * gtif, const char * tif_filename )
     x = 0.5;
     y = 0.5;
     if( !GTIFImageToPCS( gtif, &x, &y ) )
+    {
+        fprintf( stderr, "Unable to translate image to PCS coordinates.\n" );
         return;
+    }
     adfCoeff[4] = x;
     adfCoeff[5] = y;
 
@@ -326,6 +331,8 @@ static void WriteTFWFile( GTIF * gtif, const char * tif_filename )
         fprintf( fp, "%24.10f\n", adfCoeff[i] );
 
     fclose( fp );
+
+    fprintf( stderr, "World file written to '%s'.\n", tfw_filename); 
 }
 
 /************************************************************************/
