@@ -12,32 +12,6 @@
  *    20 June, 1995      Niles D. Ritter         New
  *    7 July,  1995      Greg Martin             Fix index
  *
- * $Log: geo_new.c,v $
- * Revision 1.14  2008/05/09 18:37:46  fwarmerdam
- * add support for simple tags api
- *
- * Revision 1.13  2007/10/03 04:08:03  fwarmerdam
- * avoid memory leak in case of error
- *
- * Revision 1.12  2006/06/26 20:03:37  fwarmerdam
- * If the ascii parameters list is too short for the declared size
- * of an ascii parameter, but it doesn't start off the end of the
- * available string then just trim the length.  This is to make the
- * ESRI sample data file 34105h2.tif work properly.  I wish we had
- * a way of issuing warnings!
- *
- * Revision 1.11  2004/04/27 21:32:08  warmerda
- * Allow GTIFNew(NULL) to work
- *
- * Revision 1.10  2003/09/02 13:52:17  warmerda
- * various hacks to support improperly terminated asciiparms
- *
- * Revision 1.9  2003/06/19 20:04:11  warmerda
- * fix memory underwrite if ascii parameter string is zero length
- *
- * Revision 1.8  2003/06/05 14:20:45  warmerda
- * cosmetic formatting changes
- *
  **********************************************************************/
 
 #include "geotiffio.h"   /* public interface        */
@@ -134,6 +108,11 @@ GTIF* GTIFNewWithMethods(void *tif, TIFFMethod* methods)
         header->hdr_rev_minor = GvCurrentMinorRev;
         gt->gt_nshorts=sizeof(KeyHeader)/sizeof(pinfo_t);
     }
+    else
+    {
+        /* resize data array so it can be extended if needed */
+        data = (pinfo_t*) _GTIFrealloc(data,(4+MAX_VALUES)*sizeof(pinfo_t));
+    }
     gt->gt_short = data;
     header = (KeyHeader *)data;
 	
@@ -160,6 +139,12 @@ GTIF* GTIFNewWithMethods(void *tif, TIFFMethod* methods)
         gt->gt_double=(double*)_GTIFcalloc(MAX_VALUES*sizeof(double));
         if (!gt->gt_double) goto failure;	
     }
+    else
+    {
+        /* resize data array so it can be extended if needed */
+        gt->gt_double = (double*) _GTIFrealloc(gt->gt_double,
+                                               (MAX_VALUES)*sizeof(double));
+    }
     if ( tif == NULL
          || !(gt->gt_methods.get)(tif, GTIFF_ASCIIPARAMS,
                                   &tempData.tk_asciiParamsLength,
@@ -270,11 +255,16 @@ static int ReadKey(GTIF* gt, TempKeyData* tempData,
             else if (offset + count > tempData->tk_asciiParamsLength)
                 return (0);
 
-            keyptr->gk_data = (char *) _GTIFcalloc (MAX(1,count+1));
+            keyptr->gk_count = MAX(1,count+1);
+            keyptr->gk_data = (char *) _GTIFcalloc (keyptr->gk_count);
+
             _GTIFmemcpy (keyptr->gk_data,
                          tempData->tk_asciiParams + offset, count);
             if( keyptr->gk_data[MAX(0,count-1)] == '|' )
+            {
                 keyptr->gk_data[MAX(0,count-1)] = '\0';
+                keyptr->gk_count = count;
+            }
             else
                 keyptr->gk_data[MAX(0,count)] = '\0';
             break;
